[libcxx-commits] [PATCH] D125245: [libc++abi] Reword uncaught exception termination message

Louis Dionne via Phabricator via libcxx-commits libcxx-commits at lists.llvm.org
Tue May 10 06:59:11 PDT 2022


This revision was landed with ongoing or failed builds.
This revision was automatically updated to reflect the committed changes.
Closed by commit rGead7a5fc0436: [libc++abi] Reword uncaught exception termination message (authored by ldionne).

Repository:
  rG LLVM Github Monorepo

CHANGES SINCE LAST ACTION
  https://reviews.llvm.org/D125245/new/

https://reviews.llvm.org/D125245

Files:
  libcxxabi/src/cxa_default_handlers.cpp


Index: libcxxabi/src/cxa_default_handlers.cpp
===================================================================
--- libcxxabi/src/cxa_default_handlers.cpp
+++ libcxxabi/src/cxa_default_handlers.cpp
@@ -63,17 +63,17 @@
                 {
                     // Include the what() message from the exception
                     const std::exception* e = static_cast<const std::exception*>(thrown_object);
-                    abort_message("terminating with %s exception of type %s: %s",
+                    abort_message("terminating due to %s exception of type %s: %s",
                                   cause, name, e->what());
                 }
                 else
-                    // Else just note that we're terminating with an exception
-                    abort_message("terminating with %s exception of type %s",
+                    // Else just note that we're terminating due to an exception
+                    abort_message("terminating due to %s exception of type %s",
                                    cause, name);
             }
             else
-                // Else we're terminating with a foreign exception
-                abort_message("terminating with %s foreign exception", cause);
+                // Else we're terminating due to a foreign exception
+                abort_message("terminating due to %s foreign exception", cause);
         }
     }
 #endif


-------------- next part --------------
A non-text attachment was scrubbed...
Name: D125245.428360.patch
Type: text/x-patch
Size: 1407 bytes
Desc: not available
URL: <http://lists.llvm.org/pipermail/libcxx-commits/attachments/20220510/48b454ef/attachment.bin>


More information about the libcxx-commits mailing list